==> gnome-vfs-0.1.tar.gz: gnome-vfs-0.1/libgnomevfs/gnome-vfs-private-utils.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* gnome-vfs-private-utils.h - Private utility functions for the GNOME Virtual
   File System.

   Copyright (C) 1999 Free Software Foundation

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: Ettore Perazzoli <ettore@comm2000.it> */

#ifndef _GNOME_VFS_PRIVATE_UTILS_H
#define _GNOME_VFS_PRIVATE_UTILS_H

GList 		*gnome_vfs_string_list_from_string_array (const gchar *array[]);
void	 	 gnome_vfs_free_string_list		 (GList *list);
gchar   	*gnome_vfs_canonicalize_pathname         (gchar *path);

pid_t	 	 gnome_vfs_forkexec 	(const gchar *file_name,
					 gchar *const argv[],
					 GnomeVFSProcessOptions options,
					 GnomeVFSProcessInitFunc init_func,
					 gpointer data);
GnomeVFSProcessRunResult
	 	gnome_vfs_process_run_cancellable
					(const gchar *file_name,
					 gchar *const argv[],
					 GnomeVFSProcessOptions options,
					 GnomeVFSCancellation *cancellation,
					 guint *exit_value);

GnomeVFSResult	gnome_vfs_create_temp 	(const gchar *prefix,
					 gchar **name_return,
					 GnomeVFSHandle **handle_return);
gboolean	gnome_vfs_atotm		(const gchar *time_string,
					 time_t *value_return);

#endif /* _GNOME_VFS_UTILS_H */

==> gnome-vfs-0.2.tar.gz: gnome-vfs-0.2/libgnomevfs/gnome-vfs-private-utils.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* gnome-vfs-private-utils.h - Private utility functions for the GNOME Virtual
   File System.

   Copyright (C) 1999 Free Software Foundation

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: Ettore Perazzoli <ettore@comm2000.it> */

#ifndef _GNOME_VFS_PRIVATE_UTILS_H
#define _GNOME_VFS_PRIVATE_UTILS_H

GList 		*gnome_vfs_string_list_from_string_array (const gchar * const array[]);
void	 	 gnome_vfs_free_string_list		 (GList *list);
gchar   	*gnome_vfs_canonicalize_pathname         (gchar *path);

pid_t	 	 gnome_vfs_forkexec 	(const gchar *file_name,
					 const gchar * const argv[],
					 GnomeVFSProcessOptions options,
					 GnomeVFSProcessInitFunc init_func,
					 gpointer data);
GnomeVFSProcessRunResult
	 	gnome_vfs_process_run_cancellable
					(const gchar *file_name,
					 const gchar * const argv[],
					 GnomeVFSProcessOptions options,
					 GnomeVFSCancellation *cancellation,
					 guint *exit_value);

GnomeVFSResult	gnome_vfs_create_temp 	(const gchar *prefix,
					 gchar **name_return,
					 GnomeVFSHandle **handle_return);
gboolean	gnome_vfs_atotm		(const gchar *time_string,
					 time_t *value_return);

#endif /* _GNOME_VFS_UTILS_H */
